==> fantacalciobazar_0.5.1.tar.gz: fantacalciobazar/configura.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {



if ($cambia_qualcosa) {


if ($leggi_readme) {
$linee_readme = file("README.txt");
$num_linee_readme = count($linee_readme);
for ($num1 = 0 ; $num1 < $num_linee_readme; $num1++) echo $linee_readme[$num1]."<br>";
} # fine if ($leggi_readme)


if ($salva_modifiche) {
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
if (@fopen("$percorso_cartella_dati/dati.php","w+")) {
$file_dati = fopen("$percorso_cartella_dati/dati.php","w+");
flock($file_dati,2);
$n_contenuto_dati = stripslashes($n_contenuto_dati);
fwrite($file_dati,$n_contenuto_dati);
flock($file_dati,3);
fclose($file_dati);
echo "Modifiche salvate.<br>";
} # fine if (fopen("$percorso_cartella_dati/dati.php","w+"))
else echo "<b>ERRORE</b>: si devono cambiare i permessi di scrittura del file dati.php per salvare le modifiche, leggi il README.<br>";
flock($lock,3);
fclose($lock);
} # fine if ($salva_modifiche)


if ($ripristina_dati_originale) {
if (!$sicuro) {
echo "<form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<input type=\"hidden\" name=\"ripristina_dati_originale\" value=\"$ripristina_dati_originale\">
<b>ATTENZIONE</b>: tutte le modifiche apportate a dati.php dall'installazione di fantacalciobazar
verranno cancellate! Anche il nome dei giocatori e le loro password!<br>
<input type=\"submit\" name=\"sicuro\" value=\"Continua\">
</form>";
} # fine if (!$sicuro)
else {
$dati_originale = "<?php


# 1) Giocatori e loro password (non utilizzare il nome admin). Inserire il nome
# dei partecipanti tra le virgolette (senza spazi o caratteri strani). Aggiungere o 
# togliere linee per  aggiungere o togliere giocatori. nopasswordinserita per 
# password in bianco. GIOCATORE  diverso da giocatore (le maiuscole contano!).
\$pass[\"giocatore1\"] = \"nopasswordinserita\";
\$pass[\"giocatore2\"] = \"nopasswordinserita\";
\$pass[\"giocatore3\"] = \"nopasswordinserita\";
\$pass[\"giocatore4\"] = \"nopasswordinserita\";
\$pass[\"giocatore5\"] = \"nopasswordinserita\";
\$pass[\"giocatore6\"] = \"nopasswordinserita\";
\$pass[\"giocatore7\"] = \"nopasswordinserita\";
\$pass[\"giocatore8\"] = \"nopasswordinserita\";

# 2) Password dell'amministratore e il nome con cui viene visto nei messaggi
\$passadmin = \"nopasswordinserita\";
\$nome_admin_in_messaggi = \"Presidente\";

# 3) Soldi iniziali di ogni giocatore
\$soldi_iniziali = 250;

# 4) Numero massimo di calciatori che si possono possedere
\$max_calciatori = 22;

# 5) Tempo che deve trascorrere dall'offerta per considerare comprato un calciatore 
# o scaduta un' offerta di scambio.
\$aspetta_giorni = \"04\";
\$aspetta_ore = \"00\";
\$aspetta_minuti = \"00\";

# 6) Gli schemi di gioco utilizzabili. Gli schemi a 5 numeri servono solo se si
# usano i fantasisti. Si possono aggiungere o togliere schemi.
\$schemi = array(\"1433\",\"1442\",\"1343\",\"1352\",\"1532\",\"1541\",\"1631\",\"13313\",\"14312\",\"13412\",\"15311\");

# 7) Numero di calciatori in panchina e quanti ne possono entrare. Si possono fare 
# sostituzioni per ruolo (il calciatore entra se un'altro del suo ruolo non ha giocato) o 
# per schema (il calciatore entra se entrando lo schema che si forma  tra quelli 
# consentiti). Se sia per ruolo che per schema sono a SI si sostituisce prima per ruolo.
\$max_in_panchina = 7;
\$max_entrate_dalla_panchina = 3;
\$sostituisci_per_ruolo = \"SI\";			# impostare a \"SI\" o \"NO\" (le maiuscole contano!)
\$sostituisci_fantasisti_come_centrocampisti = \"NO\";	# impostare a \"SI\" o \"NO\", usato solo con sostituzioni per ruolo, massimo 1 fantasista
\$sostituisci_per_schema = \"SI\";			# impostare a \"SI\" o \"NO\"

# 8) Numero minimo di calciatori che devono essere titolari in formazione per ottenere 
# punti (sono compresi anche quelli che non giocano). Non impostare a pi di 11.
\$min_num_titolari_in_formazione = 0;

# 9) Percentuale del costo pagato a cui si pu rivendere subito il calciatore
\$percentuale_vendita = 50;

# 10) Numero di calciatori inseribili in una offerta di scambio (0 per disabilitare 
# gli scambi) e possibilit di inserire anche soldi nello scambio.
\$num_calciatori_scambiabili = 2;
\$scambio_con_soldi = \"NO\";	# impostare a \"SI\" o \"NO\" (le maiuscole contano!)


# 11) Composizione del file con tutti i calciatori (dati/calciatori.txt)
\$separatore_campi_file_calciatori = \",\";
\$num_colonna_numcalciatore_file_calciatori = 1;
\$num_colonna_nome_file_calciatori = 2;
\$num_colonna_ruolo_file_calciatori = 3;
\$simbolo_portiere_file_calciatori = \"P\";
\$simbolo_difensore_file_calciatori = \"D\";
\$simbolo_centrocampista_file_calciatori = \"C\";
\$simbolo_fantasista_file_calciatori = \"F\";
\$simbolo_attaccante_file_calciatori = \"A\";
\$considera_fantasisti_come = \"F\";	# impostare a \"F\" per usare i fantasisti, \"C\" per considerarli centrocampisti, \"A\" attaccanti
\$num_colonna_squadra_file_calciatori = 0;	# opzionale, non c' se impostato a 0

# 12) Composizione del file con i voti di giornata (dati/votiXX.txt)
\$separatore_campi_file_voti = \",\";
\$num_colonna_numcalciatore_file_voti = 1;
\$num_colonna_vototot_file_voti = 4;
\$num_colonna_votogiornale_file_voti = 4;

# 13) Posizione del file dei voti da copiare (se non viene copiato a mano), pu
# essere anche una URL (http://...). Se il file contiene anche 01,02,... in
# corripondeza alla giornata utilizzare anche la 2,3,4 e 5 variabile.
\$prima_parte_pos_file_voti = \"\";        # parte prima del n di giornata, unica nel caso non vi sia n
\$num_giornata_file_voti = \"NO\";         # impostare a \"SI\" o \"NO\" (le maiuscole contano!)
\$num_giornata_file_voti_doppio = \"SI\";  # impostare a \"SI\" (se il n  01,02,...) o \"NO\" (se il n  1,2,...)
\$seconda_parte_pos_file_voti = \"\";      # parte che segue il n di giornata
\$diff_num_giornata_file = 0;            # differenza tra il n della giornata del file e quello del torneo di fantacalciobazar
                                     
# 14) Dove e se far vedere i risultati di giornata
\$mostra_giornate_in_login = \"SI\";	# impostare a \"SI\" o \"NO\"
\$mostra_giornate_in_mercato = \"SI\";	# impostare a \"SI\" o \"NO\"

# 15) Lista dei campionati che verranno disputati. Tra le virgolette vi devono 
# essere la giornata iniziale e quella finale separate da un -. Non sovrapporre 2 
# campionati. Si possono aggiungere o togliere linee.
\$campionato[\"1-28\"] = \"S\";		# impostare a \"S\" per scontri diretti, \"P\" per punti, \"V\" per somma voti o \"N\" per nessuno
\$campionato[\"29-31\"] = \"P\";
\$campionato[\"32-32\"] = \"N\";
\$campionato[\"33-34\"] = \"V\";

# 16) Dati per i campionati a scontri diretti. Servono solo se si  impostato
# un campionato a \"S\".
\$soglia_voti_primo_gol = 66;
\$incremento_voti_gol_successivi = 4;
\$voti_bonus_in_casa = 1;
\$punti_partita_vinta = 3;
\$punti_partita_pareggiata = 1;
\$punti_partita_persa = 0;

# 17) Dati per i campionati a punti per posizione di giornata. Servono solo se si 
# impostato un campionato a \"P\". Togliere o aggiungere linee a seconda del numero di
# giocatori
\$punti_pareggio = \"M\";		# impostare a \"M\" per la media, \"A\" per i punti della posizione pi alta o \"B\" per quelli della pi bassa
\$punti_posizione[1] = 10;	# punti assegnati al primo di giornata
\$punti_posizione[2] = 8;
\$punti_posizione[3] = 6;
\$punti_posizione[4] = 5;
\$punti_posizione[5] = 4;
\$punti_posizione[6] = 2;
\$punti_posizione[7] = 1;
\$punti_posizione[8] = 0;


# 18) Lo stato del mercato pu essere \"A\" per aperto (tutte le operazioni consentite),
# \"S\" per sospeso (consentiti solo rilanci e vendita immediata di calciatori) o \"C\"
# per chiuso (nessuna operazione di mercato consentita)
\$stato_mercato = \"A\";

# 19) Impostare a \"NO\" se si vuole che i giocatori non possano pi cambiare il nome
# e l'indirizzo del sito della loro squadra
\$nome_squadra_cambiabile = \"SI\";		# impostare a \"SI\" o \"NO\"
\$indirizzo_sito_squadra_cambiabile = \"SI\"	# impostare a \"SI\" o \"NO\"


?>";
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
if (@fopen("$percorso_cartella_dati/dati.php","w+")) {
$file_dati = fopen("$percorso_cartella_dati/dati.php","w+");
flock($file_dati,2);
fwrite($file_dati,$dati_originale);
flock($file_dati,3);
fclose($file_dati);
echo "dati.php originale ripristinato.<br>";
} # fine if (fopen("$percorso_cartella_dati/dati.php","w+"))
else echo "<b>ERRORE</b>: si devono cambiare i permessi di scrittura del file dati.php per ripristinarlo, leggi il README.<br>";
flock($lock,3);
fclose($lock);
} # fine else if (!$sicuro)
} # fine if ($ripristina_dati_originale)


echo "<center><form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($cambia_qualcosa)

else {


echo "<center><b>Edita dati.php</b></center><br>
<form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
Qualsiasi carattere dopo un #  un commento. Per spiegazioni pi dettagliate 
<input type=\"submit\" name=\"leggi_readme\" value=\"leggi il README\">.
</form>";
$linee_dati = file("$percorso_cartella_dati/dati.php");
$num_linee_dati = count($linee_dati);
echo "<center><form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<textarea name=\"n_contenuto_dati\" rows=133 cols=150>";
for ($num1 = 0 ; $num1 < $num_linee_dati; $num1++) echo $linee_dati[$num1];
echo "</textarea>
<br><input type=\"submit\" name=\"salva_modifiche\" value=\"Salva le modifiche\">
</form>
<form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<input type=\"submit\" name=\"ripristina_dati_originale\" value=\"Ripristina il dati.php iniziale di fantacalciobazar\">
</form></center>";


echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";


} # fine else if ($cambia_qualcosa)



} # fine if ($pass_admin_errata == "NO")


include("$percorso_cartella_dati/foot.php");



?>

==> fantacalciobazar_0.5.3.tar.gz: fantacalciobazar/configura.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {



if ($cambia_qualcosa) {


if ($leggi_readme) {
$linee_readme = file("README.txt");
$num_linee_readme = count($linee_readme);
for ($num1 = 0 ; $num1 < $num_linee_readme; $num1++) echo $linee_readme[$num1]."<br>";
} # fine if ($leggi_readme)


if ($salva_modifiche) {
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
if (@fopen("$percorso_cartella_dati/dati.php","w+")) {
$file_dati = fopen("$percorso_cartella_dati/dati.php","w+");
flock($file_dati,2);
$n_contenuto_dati = stripslashes($n_contenuto_dati);
fwrite($file_dati,$n_contenuto_dati);
flock($file_dati,3);
fclose($file_dati);
echo "Modifiche salvate.<br>";
} # fine if (fopen("$percorso_cartella_dati/dati.php","w+"))
else echo "<b>ERRORE</b>: si devono cambiare i permessi di scrittura del file dati.php per salvare le modifiche, leggi il README.<br>";
flock($lock,3);
fclose($lock);
} # fine if ($salva_modifiche)


if ($ripristina_dati_originale) {
if (!$sicuro) {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<input type=\"hidden\" name=\"ripristina_dati_originale\" value=\"$ripristina_dati_originale\">
<b>ATTENZIONE</b>: tutte le modifiche apportate a dati.php dall'installazione di fantacalciobazar
verranno cancellate! Anche il nome dei giocatori e le loro password!<br>
<input type=\"submit\" name=\"sicuro\" value=\"Continua\">
</form>";
} # fine if (!$sicuro)
else {
$dati_originale = "<?php


# 1) Giocatori e loro password (non utilizzare il nome admin). Inserire il nome
# dei partecipanti tra le virgolette (senza spazi o caratteri strani). Aggiungere o 
# togliere linee per  aggiungere o togliere giocatori. nopasswordinserita per 
# password in bianco. GIOCATORE è diverso da giocatore (le maiuscole contano!).
\$pass[\"giocatore1\"] = \"nopasswordinserita\";
\$pass[\"giocatore2\"] = \"nopasswordinserita\";
\$pass[\"giocatore3\"] = \"nopasswordinserita\";
\$pass[\"giocatore4\"] = \"nopasswordinserita\";
\$pass[\"giocatore5\"] = \"nopasswordinserita\";
\$pass[\"giocatore6\"] = \"nopasswordinserita\";
\$pass[\"giocatore7\"] = \"nopasswordinserita\";
\$pass[\"giocatore8\"] = \"nopasswordinserita\";

# 2) Password dell'amministratore e il nome con cui viene visto nei messaggi
\$passadmin = \"nopasswordinserita\";
\$nome_admin_in_messaggi = \"Presidente\";

# 3) Soldi iniziali di ogni giocatore
\$soldi_iniziali = 250;

# 4) Numero massimo di calciatori che si possono possedere
\$max_calciatori = 22;

# 5) Tempo che deve trascorrere dall'offerta per considerare comprato un calciatore 
# o scaduta un' offerta di scambio.
\$aspetta_giorni = \"04\";
\$aspetta_ore = \"00\";
\$aspetta_minuti = \"00\";

# 6) Gli schemi di gioco utilizzabili. Gli schemi a 5 numeri servono solo se si
# usano i fantasisti. Si possono aggiungere o togliere schemi.
\$schemi = array(\"1433\",\"1442\",\"1343\",\"1352\",\"1532\",\"1541\",\"1631\",\"13313\",\"14312\",\"13412\",\"15311\");

# 7) Numero di calciatori in panchina e quanti ne possono entrare. Si possono fare 
# sostituzioni per ruolo (il calciatore entra se un'altro del suo ruolo non ha giocato) o 
# per schema (il calciatore entra se entrando lo schema che si forma è tra quelli 
# consentiti). Se sia per ruolo che per schema sono a SI si sostituisce prima per ruolo.
\$max_in_panchina = 7;
\$max_entrate_dalla_panchina = 3;
\$sostituisci_per_ruolo = \"SI\";			# impostare a \"SI\" o \"NO\" (le maiuscole contano!)
\$sostituisci_fantasisti_come_centrocampisti = \"NO\";	# impostare a \"SI\" o \"NO\", usato solo con sostituzioni per ruolo, massimo 1 fantasista
\$sostituisci_per_schema = \"SI\";			# impostare a \"SI\" o \"NO\"

# 8) Numero minimo di calciatori che devono essere titolari in formazione per ottenere 
# punti (sono compresi anche quelli che non giocano). Non impostare a più di 11.
\$min_num_titolari_in_formazione = 0;

# 9) Percentuale del costo pagato a cui si può rivendere subito il calciatore
\$percentuale_vendita = 50;

# 10) Numero di calciatori inseribili in una offerta di scambio (0 per disabilitare 
# gli scambi) e possibilità di inserire anche soldi nello scambio.
\$num_calciatori_scambiabili = 2;
\$scambio_con_soldi = \"NO\";	# impostare a \"SI\" o \"NO\" (le maiuscole contano!)


# 11) Composizione del file con tutti i calciatori (dati/calciatori.txt)
\$separatore_campi_file_calciatori = \",\";
\$num_colonna_numcalciatore_file_calciatori = 1;
\$num_colonna_nome_file_calciatori = 2;
\$num_colonna_ruolo_file_calciatori = 3;
\$simbolo_portiere_file_calciatori = \"P\";
\$simbolo_difensore_file_calciatori = \"D\";
\$simbolo_centrocampista_file_calciatori = \"C\";
\$simbolo_fantasista_file_calciatori = \"F\";
\$simbolo_attaccante_file_calciatori = \"A\";
\$considera_fantasisti_come = \"F\";	# impostare a \"F\" per usare i fantasisti, \"C\" per considerarli centrocampisti, \"A\" attaccanti
\$num_colonna_squadra_file_calciatori = 0;	# opzionale, non c'è se impostato a 0

# 12) Composizione del file con i voti di giornata (dati/votiXX.txt)
\$separatore_campi_file_voti = \",\";
\$num_colonna_numcalciatore_file_voti = 1;
\$num_colonna_vototot_file_voti = 4;
\$num_colonna_votogiornale_file_voti = 4;
\$chiave_codifica_xor = \"\"; # Inserire la chiave se il file è codificato con xor

# 13) Posizione del file dei voti da copiare (se non viene copiato a mano), può
# essere anche una URL (http://...). Se il file contiene anche 01,02,... in
# corripondeza alla giornata utilizzare anche la 2a,3a,4a e 5a variabile.
\$prima_parte_pos_file_voti = \"\";        # parte prima del n° di giornata, unica nel caso non vi sia n°
\$num_giornata_file_voti = \"NO\";         # impostare a \"SI\" o \"NO\" (le maiuscole contano!)
\$num_giornata_file_voti_doppio = \"SI\";  # impostare a \"SI\" (se il n° è 01,02,...) o \"NO\" (se il n° è 1,2,...)
\$seconda_parte_pos_file_voti = \"\";      # parte che segue il n° di giornata
\$diff_num_giornata_file = 0;            # differenza tra il n° della giornata del file e quello del torneo di fantacalciobazar
                                     
# 14) Dove e se far vedere i risultati di giornata
\$mostra_giornate_in_login = \"SI\";	# impostare a \"SI\" o \"NO\"
\$mostra_giornate_in_mercato = \"SI\";	# impostare a \"SI\" o \"NO\"

# 15) Lista dei campionati che verranno disputati. Tra le virgolette vi devono 
# essere la giornata iniziale e quella finale separate da un -. Non sovrapporre 2 
# campionati. Si possono aggiungere o togliere linee.
\$campionato[\"1-28\"] = \"S\";		# impostare a \"S\" per scontri diretti, \"P\" per punti, \"V\" per somma voti o \"N\" per nessuno
\$campionato[\"29-31\"] = \"P\";
\$campionato[\"32-32\"] = \"N\";
\$campionato[\"33-34\"] = \"V\";

# 16) Dati per i campionati a scontri diretti. Servono solo se si è impostato
# un campionato a \"S\".
\$soglia_voti_primo_gol = 66;
\$incremento_voti_gol_successivi = 4;
\$voti_bonus_in_casa = 1;
\$punti_partita_vinta = 3;
\$punti_partita_pareggiata = 1;
\$punti_partita_persa = 0;

# 17) Dati per i campionati a punti per posizione di giornata. Servono solo se si è
# impostato un campionato a \"P\". Togliere o aggiungere linee a seconda del numero di
# giocatori
\$punti_pareggio = \"M\";		# impostare a \"M\" per la media, \"A\" per i punti della posizione più alta o \"B\" per quelli della più bassa
\$punti_posizione[1] = 10;	# punti assegnati al primo di giornata
\$punti_posizione[2] = 8;
\$punti_posizione[3] = 6;
\$punti_posizione[4] = 5;
\$punti_posizione[5] = 4;
\$punti_posizione[6] = 2;
\$punti_posizione[7] = 1;
\$punti_posizione[8] = 0;

# 18) Modificatore della difesa
\$num_minimo_difensori_modificatore = 4; # Numero minimo di difensori per attivare il modificatore. Impostare a 0 per disattivare il modificatore
\$num_difensori_media_modificatore = 3; # numero dei difensori con voti migliori che fanno media
\$portiere_in_media_modificatore = \"SI\"; # se il portire deve essere considerato nella media
\$media_limite_bonus_1 = 6; # la media che attiva il primo bonus 
\$punti_bonus_1 = 1; # punti che assegna il primo bonus
\$media_limite_bonus_2 = 6.5;
\$punti_bonus_2 = 2;
\$media_limite_bonus_3 = 7;
\$punti_bonus_3 = 3;


# 19) Lo stato del mercato può essere \"A\" per aperto (tutte le operazioni consentite),
# \"S\" per sospeso (consentiti solo rilanci e vendita immediata di calciatori) o \"C\"
# per chiuso (nessuna operazione di mercato consentita)
\$stato_mercato = \"A\";

# 20) Impostare a \"NO\" se si vuole che i giocatori non possano più cambiare il nome
# e l'indirizzo del sito della loro squadra
\$nome_squadra_cambiabile = \"SI\";		# impostare a \"SI\" o \"NO\"
\$indirizzo_sito_squadra_cambiabile = \"SI\"	# impostare a \"SI\" o \"NO\"


?>";
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
if (@fopen("$percorso_cartella_dati/dati.php","w+")) {
$file_dati = fopen("$percorso_cartella_dati/dati.php","w+");
flock($file_dati,2);
fwrite($file_dati,$dati_originale);
flock($file_dati,3);
fclose($file_dati);
echo "dati.php originale ripristinato.<br>";
} # fine if (fopen("$percorso_cartella_dati/dati.php","w+"))
else echo "<b>ERRORE</b>: si devono cambiare i permessi di scrittura del file dati.php per ripristinarlo, leggi il README.<br>";
flock($lock,3);
fclose($lock);
} # fine else if (!$sicuro)
} # fine if ($ripristina_dati_originale)


echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($cambia_qualcosa)

else {


echo "<center><b>Edita dati.php</b></center><br>
<form  accept-charset=\"utf-8\" method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
Qualsiasi carattere dopo un # è un commento. Per spiegazioni più dettagliate 
<input type=\"submit\" name=\"leggi_readme\" value=\"leggi il README\">.
</form>";
$linee_dati = file("$percorso_cartella_dati/dati.php");
$num_linee_dati = count($linee_dati);
echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<textarea name=\"n_contenuto_dati\" rows=145 cols=150>";
for ($num1 = 0 ; $num1 < $num_linee_dati; $num1++) echo $linee_dati[$num1];
echo "</textarea>
<br><input type=\"submit\" name=\"salva_modifiche\" value=\"Salva le modifiche\">
</form>
<form  accept-charset=\"utf-8\" method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
<input type=\"submit\" name=\"ripristina_dati_originale\" value=\"Ripristina il dati.php iniziale di fantacalciobazar\">
</form></center>";


echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";


} # fine else if ($cambia_qualcosa)



} # fine if ($pass_admin_errata == "NO")


include("$percorso_cartella_dati/foot.php");



?>
